==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/setup.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


require_once($languagePath . 'p_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_setup'] = 							"setup";
$lang['txt_messaging'] = 						"messaging";


//SUBMIT BUTTONS
$lang['sub_finish'] = 							"FINISHED";


//A HREF TAGS (links)
$lang['href_index'] = 							"go to the login page";

//BODY TEXT
$lang['txt_invite_to_help'] =					"Type in your friends email addresses. You can either put one of each line or use a comma (,) between them like 'support@aroundme.org, info@aroundme.org'. Please don't send more that 20 emails at a time.";
$lang['txt_default_library_title'] = 			"welcome";
$lang['txt_default_library_synopsis'] = 		"default library item";
$lang['txt_default_library_page_name'] = 		"MyFirstPage"; //must be WIKI formatted LikeThisExample
$lang['txt_invite'] =							"You have been invited into Barnraiser!";
$lang['txt_invite_message_txt'] =				"Join me in aroundme!";
$lang['txt_intro'] =							"Welcome to aroundme where you can join groups and activities with your friends....just need a little setting up first. You just need to do 3 things:";
$lang['txt_access_code'] = 						"enter your access code";
$lang['txt_access_code_help'] =					"You were sent an email with an access code. Enter the code here.";
$lang['txt_create_password'] = 					"create your password";
$lang['txt_create_password_help'] =				"Use a password that no one will guess. It has to be at least 5 characters long and with no spaces. Remember that it will be case sensitive, so 'Barnraiser' is not the same as 'barnraiser'.";
$lang['txt_password1'] = 						"Type in a password.";
$lang['txt_password2'] = 						"Repeat your password.";
$lang['txt_add_friends'] = 						"add your friends";
$lang['txt_add_friends_help'] = 				"Type in the email addresses of up to 20 of your friends.";
$lang['txt_hi'] = 								"Hi"; //a greeting, Hi Tom,
$lang['txt_already_setup'] = 					"You've already set up with us. Click the link below.";
$lang['txt_default_library_body'] = 			"I've not started my scrapbook yet.";
$lang['txt_finish'] = 							"you're done";
$lang['txt_finish_help'] = 						"Now your done. Press 'finished' and you will enter 'aroundme'.";
$lang['txt_messaging_help'] = 					"Would you like to set your default profile to allow people can send you messages? (you can change it later)";
?>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/setup.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


require_once($languagePath . 'p_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_setup'] = 							"setup";
$lang['txt_messaging'] = 						"messaging and email";


//SUBMIT BUTTONS
$lang['sub_finish'] = 							"FINISHED";


//A HREF TAGS (links)
$lang['href_index'] = 							"go to the login page";


//BODY TEXT
$lang['txt_invite_to_help'] =					"Type in your friends email addresses. You can either put one of each line or use a comma (,) between them like 'support@barnraiser.org, info@barnraiser.org'. Please don't send more that 20 emails at a time.";
$lang['txt_default_library_title'] = 			"welcome";
$lang['txt_default_library_synopsis'] = 		"default library item";
$lang['txt_default_library_page_name'] = 		"MyFirstPage"; //must be WIKI formatted LikeThisExample
$lang['txt_invite'] =							"You have been invited into AROUNDMe!";
$lang['txt_invite_message_txt'] =				"Join me in AROUNDMe!";
$lang['txt_intro'] =							"Welcome to AROUNDMe where you can join groups and activities with your friends....just need a little setting up first. You just need to do 3 things:";
$lang['txt_access_code'] = 						"enter your access code";
$lang['txt_access_code_help'] =					"You were sent an email with an access code. Enter the code here.";
$lang['txt_create_password'] = 					"create your password";
$lang['txt_create_password_help'] =				"Use a password that no one will guess. It has to be at least 5 characters long and with no spaces. Remember that it will be case sensitive, so 'Barnraiser' is not the same as 'barnraiser'.";
$lang['txt_password1'] = 						"Type in a password.";
$lang['txt_password2'] = 						"Repeat your password.";
$lang['txt_add_friends'] = 						"add your friends";
$lang['txt_add_friends_help'] = 				"Type in the email addresses of up to 20 of your friends.";
$lang['txt_hi'] = 								"Hi"; //a greeting, Hi Tom,
$lang['txt_already_setup'] = 					"You've already set up with us. Click the link below.";
$lang['txt_default_library_body'] = 			"I've not started my wiki yet.";
$lang['txt_finish'] = 							"you're done";
$lang['txt_finish_help'] = 						"Now your done. Press 'finished' and you will enter AROUNDMe.";
$lang['txt_messaging_help'] = 					"Would you like to set your default profile to allow people can send you messages?";
$lang['txt_email_message_help'] = 				"Would you like us to send you a notification email when you receive a message?";
$lang['txt_digest_newsletter_help'] = 			"Would you like us to send you a weekly newsletter containing the latest updates and statistics.";

?>
